
<div align="center">
  <img src="https://upload.wikimedia.org/wikipedia/commons/6/6f/Spain_flag_300.png" alt="Spanish Flag" width="200" margin='auto'>
  <h1>Aprendo</h1>
</div>

![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)



[![Connect on LinkedIn](https://img.shields.io/badge/Connect%20on-LinkedIn-blue.svg)](https://www.linkedin.com/in/lucien-holliday/)
[![GitHub issues](https://img.shields.io/github/issues/luiHoll97/aprendo)](https://github.com/luiHoll97/aprendo/issues)
[![GitHub forks](https://img.shields.io/github/forks/luiHoll97/aprendo)](https://github.com/luiHoll97/aprendo/network/members)
[![GitHub contributors](https://img.shields.io/github/contributors/luiHoll97/aprendo)](https://github.com/luiHoll97/aprendo/graphs/contributors)
[![PyPI version](https://badge.fury.io/py/aprendo.svg)]()
[![License](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)
[![Documentation](https://img.shields.io/badge/Documentation-Wiki-brightgreen)](https://github.com/luiHoll97/aprendo/wiki)

# Introduction

Welcome to Aprendo!